@@ -35,7 +35,7 @@ class ReadableEnum(object):
 
 
 # 板块类型
-class SectorType(enum.Enum):
+class SectorType(enum.IntEnum):
     industry = 1
     topic = 2
     strategy = 3
@@ -43,14 +43,14 @@ class SectorType(enum.Enum):
 
 
 # 指数价格数据来源类型
-class IndexPriceSource(enum.Enum):
+class IndexPriceSource(enum.IntEnum):
     default = 1
     none = 2
     macroeconomic = 3
 
 
 # 基金收费模式
-class CodeFeeMode(enum.Enum):
+class CodeFeeMode(enum.IntEnum):
     none = 0
     a_type = 1  # 前端收费
     b_type = 2  # 后端收费
