@@ -6,11 +6,12 @@ from sqlalchemy import distinct
 from sqlalchemy.sql import func
 import pandas as pd
 
+from ...util.singleton import Singleton
 from ..wrapper.mysql import BasicDatabaseConnector
 from ..view.basic_models import *
 
 
-class BasicDataApi(object):
+class BasicDataApi(metaclass=Singleton):
     def get_trading_day_list(self, start_date='', end_date=''):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -617,7 +618,7 @@ class BasicDataApi(object):
                     ).one_or_none()
                     if dt:
                         dt = dt[0]
-                    
+
                 query = db_session.query(
                     FundHoldStock
                 ).filter(
@@ -656,3 +657,20 @@ class BasicDataApi(object):
                 return True
             except Exception as e:
                 print(f'Failed to delete data <err_msg> {e} from {FundRate.__tablename__}')
+
+    @staticmethod
+    def get_model_data(model: Base, *params):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        *(getattr(model, k) for k in params if hasattr(model, k))
+                    )
+                tag_df = pd.read_sql(query.statement, query.session.bind)
+                return tag_df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {model.__tablename__}')
+
+    @classmethod
+    def get_fund_info_data(cls, *params):
+        return cls.get_model_data(FundInfo, *params)
