@@ -1,14 +1,16 @@
 
-from typing import Tuple
+from typing import Tuple, List
 
-import math
 import pandas as pd
-import pickle as pkl
+import datetime
+from sqlalchemy import func
+
+from ...util.singleton import Singleton
 from ..wrapper.mysql import DerivedDatabaseConnector
 from ..view.derived_models import *
 
 
-class DerivedDataApi(object):
+class DerivedDataApi(metaclass=Singleton):
     def get_fund_indicator(self, fund_list):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
@@ -101,6 +103,22 @@ class DerivedDataApi(object):
                 print(f'Failed to get data <err_msg> {e} from {FundScoreExtended.__tablename__}')
                 return pd.DataFrame([])
 
+    def get_latest_fund_score_new_by_id(self, fund_id):
+        with DerivedDatabaseConnector().managed_session() as quant_session:
+            try:
+                query = quant_session.query(
+                    FundScoreNew,
+                ).filter(
+                    FundScoreNew.fund_id == fund_id,
+                ).order_by(
+                    FundScoreNew.datetime.desc()
+                ).limit(1)
+
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundScoreNew.__tablename__}')
+                return pd.DataFrame([])
+
     def get_fund_score_extended(self, start_date: str, end_date: str, fund_list: Tuple[str] = (), columns: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
@@ -267,3 +285,116 @@ class DerivedDataApi(object):
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundManagerScore.__tablename__}')
+
+    def get_latest_fund_style_box(self):
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            try:
+                sub_q = mn_session.query(
+                    StyleBox.fund_id.label('temp_id'),
+                    func.max(StyleBox.datetime).label('temp_date'),
+                ).group_by(StyleBox.fund_id).subquery()
+
+                query = mn_session.query(
+                    StyleBox.fund_id,
+                    StyleBox.x,
+                    StyleBox.y,
+                    StyleBox.datetime,
+                ).filter(
+                    StyleBox.fund_id == sub_q.c.temp_id,
+                    StyleBox.datetime == sub_q.c.temp_date
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_latest_fund_style_box {e} from {StyleBox.__tablename__}')
+                return
+
+    def get_fund_style_box(self, fund_id: Tuple[str] = (), datetime: str = ''):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    StyleBox
+                )
+                if fund_id:
+                    query = query.filter(
+                        StyleBox.fund_id.in_(fund_id),
+                    )
+                if datetime:
+                    query = query.filter(
+                        StyleBox.datetime == datetime,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_fund_style_box {e} from {StyleBox.__tablename__}')
+                return
+
+    def get_new_share_fund_rank(self):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    NewShareFundRank
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_new_share_fund_rank {e} from {NewShareFundRank.__tablename__}')
+                return
+
+    def get_convertible_bond_fund_rank(self):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    ConvertibleBondFundRank
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_convertible_bond_fund_rank {e} from {ConvertibleBondFundRank.__tablename__}')
+                return
+
+    def get_abs_return_fund_rank(self):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    AbsReturnFundRank
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_abs_return_fund_rank {e} from {AbsReturnFundRank.__tablename__}')
+                return
+
+    def delete_fund_style_box(self, date_to_delete: datetime.date, fund_list: List[str]):
+        with DerivedDatabaseConnector().managed_session() as db_session:
+            try:
+                db_session.query(
+                    StyleBox
+                ).filter(
+                    StyleBox.fund_id.in_(fund_list),
+                    StyleBox.datetime == date_to_delete,
+                ).delete(synchronize_session=False)
+                db_session.commit()
+                return True
+            except Exception as e:
+                print(f'Failed to delete data <err_msg> {e} from {StyleBox.__tablename__}')
+
+    def get_fund_manager_info(self, mng_list: Tuple[str] = (), fund_list: Tuple[str] = (), columns: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as quant_session:
+            try:
+                if columns:
+                    query = quant_session.query(
+                        FundManagerInfo.mng_id,
+                        FundManagerInfo.start_date,
+                        FundManagerInfo.fund_id,
+                    ).add_columns(*columns)
+                else:
+                    query = quant_session.query(
+                        FundManagerInfo,
+                    )
+                if mng_list:
+                    query = query.filter(
+                        FundManagerInfo.mng_id.in_(mng_list),
+                    )
+                if fund_list:
+                    query = query.filter(
+                        FundManagerInfo.fund_id.in_(fund_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundManagerInfo.__tablename__}')
