@@ -1,6 +1,6 @@
 
 import datetime
-from typing import List, Tuple, Optional
+from typing import List, Tuple, Optional, Dict
 import pandas as pd
 import traceback
 import numpy as np
@@ -12,18 +12,22 @@ import numpy as np
 
 from ...api.basic import BasicDataApi
 from ...api.derived import DerivedDataApi
-from ...view.derived_models import FundScoreExtended
-from .derived_data_helper import DerivedDataHelper, normalize, score_rescale, cont_rescale
+from ...view.derived_models import FundScoreNew
+from .derived_data_helper import DerivedDataHelper, FUND_CLASSIFIER, normalize, score_rescale, cont_rescale
 
 
 class FundScoreGroupProcess:
 
-    _SPECIAL_LIST = ('国际(QDII)基金', '另类投资基金')
+    _SPECIAL_LIST = ['国际(QDII)基金']
     _FEATURE_RANGE = (0.8, 1.2)
 
     def __init__(self, data_helper: DerivedDataHelper):
         self._data_helper = data_helper
         self._result: Optional[pd.DataFrame] = None
+        self._wind_class_to_type: Dict[str, str] = {}
+        for k, v in FUND_CLASSIFIER.items():
+            for one in v:
+                self._wind_class_to_type[one] = k
 
     def init(self, start_date: str, end_date: str):
         self._end_date = end_date
@@ -32,10 +36,13 @@ class FundScoreGroupProcess:
         self._fund_indicator_group: pd.DataFrame = DerivedDataApi().get_fund_indicator_group(start_date, end_date).drop(columns='_update_time').set_index('fund_id')
         # 过滤掉scale为0的fund
         self._fund_indicator_group = self._fund_indicator_group[self._fund_indicator_group.scale > 0]
+        # 基金经理评分以及基金经理信息
+        self._fund_manager_score: pd.DataFrame = DerivedDataApi().get_fund_manager_score(start_date=start_date, end_date=end_date).drop(columns='_update_time').set_index(['manager_id', 'fund_type'])
+        self._fund_manager_info: pd.dataFrame = DerivedDataApi().get_fund_manager_info().drop(columns='_update_time').set_index('fund_id')
 
     @staticmethod
     def _get_columns_weight_by_wind_class(wind_class: str) -> Tuple[List[str], List[float]]:
-        if wind_class in ('偏股混合型基金', '普通股票型基金', '平衡混合型基金', '灵活配置型基金'):
+        if wind_class in ('偏股混合型基金', '普通股票型基金', '平衡混合型基金', '灵活配置型基金', '股票多空'):
             columns_weight = {'annual_ret': 0.2, 'sharpe': 0.6, 'info_ratio': 0.15, 'continue_stats_v': 0.05}
         elif wind_class in ('中长期纯债型基金', '短期纯债型基金', '混合债券型一级基金', '混合债券型二级基金', '偏债混合型基金', '货币市场型基金'):
             columns_weight = {'annual_ret': 0.3, 'sharpe': 0.6, 'continue_stats_v': 0.1}
@@ -43,17 +50,27 @@ class FundScoreGroupProcess:
             columns_weight = {'annual_ret': 0.2, 'continue_stats_v': 0.05, 'alpha': 0.75}
         elif wind_class in ('被动指数型基金', '被动指数型债券基金'):
             columns_weight = {'annual_ret': 0.2, 'continue_stats_v': 0.1, 'treynor': 0.7}
-        elif wind_class in ('国际(QDII)基金', '另类投资基金'):
+        elif wind_class in ('国际(QDII)基金', 'REITs', '商品型基金'):
             columns_weight = {'annual_ret': 0.2, 'sharpe': 0.175, 'info_ratio': 0.175, 'continue_stats_v': 0.1, 'alpha': 0.175, 'treynor': 0.175}
         else:
             assert False, f'invalid wind class!! {wind_class}'
         return list(columns_weight.keys()), list(columns_weight.values())
 
     def _calc_score(self, x: pd.DataFrame, by_key: str) -> pd.DataFrame:
+
+        def _calc_fund_manager_score(fund_x: pd.Series) -> Optional[float]:
+            try:
+                wind_class_2 = self._fund_info.at[fund_x.name, 'wind_class_2']
+                our_type: str = self._wind_class_to_type[wind_class_2]
+                managers = self._fund_manager_info.loc[fund_x.name, 'mng_id']
+                return self._fund_manager_score.loc[(managers, our_type), 'score'].mean()
+            except KeyError:
+                pass
+
         fin_data: pd.DataFrame = self._fund_indicator_group.loc[x.index.intersection(self._fund_indicator_group.index), :]
         wind_class: str = x[by_key].array[0]
 
-        if wind_class in ('偏股混合型基金', '普通股票型基金', '平衡混合型基金', '灵活配置型基金'):
+        if wind_class in ('偏股混合型基金', '普通股票型基金', '平衡混合型基金', '灵活配置型基金', '股票多空'):
             data_to_calc_ret: pd.DataFrame = fin_data[fin_data.sharpe >= -20]
         else:
             data_to_calc_ret: pd.DataFrame = fin_data[fin_data.alpha <= 20]
@@ -72,7 +89,7 @@ class FundScoreGroupProcess:
         elif wind_class in ('被动指数型基金', '被动指数型债券基金'):
             track_temp = data_to_calc_ret['track_err']
             result1['return_score'] = score_rescale(-track_temp)
-        elif wind_class in ('偏股混合型基金', '平衡混合型基金', '灵活配置型基金'):
+        elif wind_class in ('偏股混合型基金', '平衡混合型基金', '灵活配置型基金', '股票多空'):
             ret_temp = 0.6 * normalize(data_to_calc_ret['sharpe']) + 0.2 * normalize(data_to_calc_ret['info_ratio']) + 0.2 * normalize(data_to_calc_ret['annual_ret'])
             result1['return_score'] = score_rescale(ret_temp * cont_rescale(data_to_calc_ret['continue_stats_v'], feature_range=self._FEATURE_RANGE))
         elif wind_class in ('偏债混合型基金', '中长期纯债型基金', '短期纯债型基金', '混合债券型一级基金', '混合债券型二级基金'):
@@ -93,7 +110,7 @@ class FundScoreGroupProcess:
         result2['robust_score'] = score_rescale(-normalize(data_to_calc_others[['annual_vol']]))
 
         # 第三个维度打分
-        if wind_class in ('偏股混合型基金', '普通股票型基金', '平衡混合型基金', '灵活配置型基金', '增强指数型基金', '被动指数型基金'):
+        if wind_class in ('偏股混合型基金', '普通股票型基金', '平衡混合型基金', '灵活配置型基金', '增强指数型基金', '被动指数型基金', '股票多空'):
             risk_temp = normalize(-data_to_calc_others['mdd']) + normalize(-data_to_calc_others['mdd_len']) + normalize(data_to_calc_others['VaR']) + normalize(data_to_calc_others['CVaR'])
         elif wind_class in ('偏债混合型基金', '中长期纯债型基金', '短期纯债型基金', '混合债券型一级基金', '混合债券型二级基金', '增强指数型债券基金', '被动指数型债券基金'):
             risk_temp = normalize(-data_to_calc_others['mdd']) + normalize(data_to_calc_others['VaR']) + normalize(data_to_calc_others['CVaR']) + normalize(np.log(data_to_calc_others['scale'])) + normalize(-data_to_calc_others['ins_holds'])
@@ -102,7 +119,7 @@ class FundScoreGroupProcess:
             risk_temp = normalize(np.log(data_to_calc_others['scale'])) + normalize(-data_to_calc_others['ins_holds']) + normalize(-data_to_calc_others['leverage']) + normalize(-data_to_calc_others['ptm'])
         else:
             risk_temp = normalize(-data_to_calc_others['mdd']) + normalize(data_to_calc_others['VaR'])
-        result2['allocation_score'] = score_rescale(risk_temp)
+        result2['risk_score'] = score_rescale(risk_temp)
 
         # 第四个和第五个维度计算
         if wind_class in ('货币市场型基金', '被动指数型基金', '被动指数型债券基金'):
@@ -114,10 +131,12 @@ class FundScoreGroupProcess:
             result2['timing_score'] = score_rescale(normalize(data_to_calc_others[['stock_cl_beta']]))
             result2['selection_score'] = score_rescale(normalize(data_to_calc_others[['stock_cl_alpha']]))
 
-        # 等待第六个版本
+        # 第六个维度 基金经理评分
+        result3 = pd.DataFrame(index=fin_data.index)
+        result3['team_score'] = fin_data.apply(_calc_fund_manager_score, axis=1)
 
         # 合并所有的评分并计算总分
-        total = result1.join(result2, how='outer')
+        total = result1.join(result2, how='outer').join(result3, how='outer')
         total['total_score'] = score_rescale(normalize(total.sum(axis=1).to_frame()))
         return total
 
@@ -139,7 +158,7 @@ class FundScoreGroupProcess:
         try:
             self.init(start_date, end_date)
             self.calc()
-            self._data_helper._upload_derived(self._result.reset_index(), FundScoreExtended.__table__.name)
+            self._data_helper._upload_derived(self._result.reset_index(), FundScoreNew.__table__.name)
         except Exception as e:
             print(e)
             traceback.print_exc()
