@@ -1,5 +1,4 @@
-#import sys
-#sys.path.append("/Users/puyuantech/Documents/GitHub/surfing/python")
+
 from typing import List, Dict
 import pandas as pd
 import numpy as np
@@ -7,14 +6,12 @@ import math
 import datetime
 import traceback
 import json
-import math
 import statsmodels.api as sm
 from scipy.optimize import Bounds, minimize
 from statsmodels.tsa.ar_model import AutoReg
 from ...api.basic import BasicDataApi
 from ...view.derived_models import FundIndicatorGroup
-#from surfing.data.api.basic import BasicDataApi
-#from surfing.data.view.derived_models import FundIndicatorGroup
+from .derived_data_helper import DerivedDataHelper
 
 
 class FundIndicatorProcessorGroup:
@@ -23,9 +20,9 @@ class FundIndicatorProcessorGroup:
     _NATURAL_DAYS_PER_YEAR = 365
     _RISK_FEE_RATE = 0.011
     _RISK_FEE_RATE_PER_DAY = _RISK_FEE_RATE / _TRADING_DAYS_PER_YEAR
-    _REPORT_DATE_LIST = [ '0331','0630', '0930','1231']
+    _REPORT_DATE_LIST = ['0331', '0630', '0930', '1231']
 
-    def __init__(self, data_helper):
+    def __init__(self, data_helper: DerivedDataHelper):
         self._data_helper = data_helper
         self._basic_api = BasicDataApi()
         self._rank_dic: Dict[pd.DataFrame] = {}
@@ -60,6 +57,8 @@ class FundIndicatorProcessorGroup:
         self._index_price: pd.DataFrame = index_price.pivot_table(index='datetime', columns='index_id', values='close').reindex(self._trading_days.index).fillna(method='ffill')
         _bank_rate_df: pd.DataFrame = self._basic_api.get_index_price(index_list=['ddir', 'nonor', 'tmd_1y', 'tmd_2y', 'tmd_3m', 'tmd_3y', 'tmd_5y', 'tmd_6m', 'tmd_7d']).drop(columns='_update_time')
         _bank_rate_df = _bank_rate_df.pivot_table(index='datetime', columns='index_id', values='close').reindex(all_trading_days.index).fillna(method='ffill').reindex(self._trading_days.index)
+        drop_list = [i for i in self._index_price if i in _bank_rate_df]
+        self._index_price = self._index_price.drop(drop_list, axis=1)
         self._index_price: pd.DataFrame = pd.concat([self._index_price, _bank_rate_df], axis=1)
         # 再reindex到参与计算的交易日列表上
         # self._index_price: pd.DataFrame = index_price.reindex(self._trading_days.index)
@@ -109,20 +108,14 @@ class FundIndicatorProcessorGroup:
             real_date = datetime.date(end_date_dt.year - 1, 12, 31)
         else:
             real_date = datetime.date(end_date_dt.year, 6, 30)
-          
-        # 取出持仓数据      
+
+        # 取出持仓数据
         self._fund_hold = self._basic_api.get_history_fund_size()
         self._fund_hold = self._fund_hold[self._fund_hold.datetime == real_date][['fund_id','institution_holds','hold_num']].reset_index()
-        if sentry.empty:  
-            real_date_2 = datetime.date(end_date_dt.year - 1, 12, 31)
-        else:
-            real_date_2 = pd.to_datetime(str(end_date_dt.year)+sentry.array[-1], infer_datetime_format=True).date()
         # 取出货基风险相关数据
         self._risk_metric = self._basic_api.get_fund_hold_asset_by_id()
         self._risk_metric = self._risk_metric[self._risk_metric.datetime == real_date][['fund_id','first_repo_to_nav','avg_ptm']].reset_index()
 
-        
-
     def df_resample(self, df):
         df.index = pd.to_datetime(df.index)
         df = df.resample('1W').sum()
@@ -325,19 +318,22 @@ class FundIndicatorProcessorGroup:
             continue_regress_v = res.params[0]
             continue_regress_t = res.tvalues[0]
 
-        _rank_df = self._rank_dic[wind_2_class]
-        res = []
-        last = ''
-        for idx, i in enumerate(_rank_df[fund_id]):
-            now = 'W' if i > 0.5 else 'L'
-            if idx != 0:
-                res.append(last+now)
-            last = now
-        ww = max(res.count('WW'), 1)
-        ll = max(res.count('LL'), 1)
-        wl = max(res.count('WL'), 1)
-        lw = max(res.count('LW'), 1)
-        continue_stats_v = ww * ll / wl / lw
+        if wind_2_class is not None:
+            _rank_df = self._rank_dic[wind_2_class]
+            res = []
+            last = ''
+            for idx, i in enumerate(_rank_df[fund_id]):
+                now = 'W' if i > 0.5 else 'L'
+                if idx != 0:
+                    res.append(last+now)
+                last = now
+            ww = max(res.count('WW'), 1)
+            ll = max(res.count('LL'), 1)
+            wl = max(res.count('WL'), 1)
+            lw = max(res.count('LW'), 1)
+            continue_stats_v = ww * ll / wl / lw
+        else:
+            continue_stats_v = np.nan
 
         # 取最后一年的有效收益率+业绩比较基准收益率
         df_i: np.ndarray = self._fund_ret[[fund_id]].join(self._benchmark_ret[fund_id], rsuffix='_b').to_numpy()
@@ -352,7 +348,6 @@ class FundIndicatorProcessorGroup:
         df_i_mmf = df_i_mmf[(~np.isnan(df_i_mmf)).all(axis=1)]
         df_i_mmf = df_i_mmf[-self._TRADING_DAYS_PER_YEAR:]
 
-
         # alpha, beta
         alpha, beta = self._lambda_alpha_beta(df_i)
         # alpha, beta to the market
@@ -395,7 +390,7 @@ class FundIndicatorProcessorGroup:
         # VaR
         ret = df_i[:, 0]
         VaR = np.quantile(ret, 0.05)
-        CVaR = ret[ret<=VaR].mean()
+        CVaR = ret[ret <= VaR].mean()
         # institution holds & hold_num
         if fund_id in self._fund_hold.fund_id.values:
             temp_hold = self._fund_hold[self._fund_hold.fund_id == fund_id]
@@ -413,10 +408,6 @@ class FundIndicatorProcessorGroup:
             leverage = np.nan
             ptm = np.nan
 
-
-        
-        
-
         stock_tm_res = self._lambda_tm(df_i)
         stock_tm_alpha = stock_tm_res['alpha']
         stock_tm_alpha_t = stock_tm_res['alpha_t']
@@ -506,7 +497,7 @@ class FundIndicatorProcessorGroup:
             self.init(start_date, end_date)
             print('init done, to calc indicators')
             self.calculate()
-            #self._result.to_csv('result.csv')
+            # self._result.to_csv('result.csv')
             self._data_helper._upload_derived(self._result, FundIndicatorGroup.__table__.name)
         except Exception as e:
             print(e)
@@ -514,9 +505,8 @@ class FundIndicatorProcessorGroup:
             failed_tasks.append('fund_indicator_group')
         return failed_tasks
 
-if __name__ == '__main__':
-    from .derived_data_helper import DerivedDataHelper
 
-    date = '20200824'
+if __name__ == '__main__':
+    date = '20200904'
     fsg = FundIndicatorProcessorGroup(DerivedDataHelper())
     fsg.process(date, date, pd.to_datetime(date).date())
