@@ -10,6 +10,7 @@ from ...manager.manager_fund import FundDataManager
 from ...manager.score import FundScoreManager
 from ...wrapper.mysql import DerivedDatabaseConnector
 from ...view.derived_models import *
+from .derived_data_helper import DerivedDataHelper
 
 class FundIndicatorProcessor(object):
 
@@ -62,12 +63,13 @@ class FundIndicatorProcessor(object):
             if self.end_date > fund_end_date:
                 self.fund_nav.loc[fund_end_date:,fund_id] = np.nan
         self.fund_ret = np.log(self.fund_nav / self.fund_nav.shift(1))
-        self.fund_ret = self.fund_ret.stack().reset_index(level=[0,1]).rename(columns={0:'ret'})        
-        self.fund_ret['index_id'] = self.fund_ret.fund_id.apply(lambda x: self.fund_to_index_dict[x])
-        self.fund_ret = self.fund_ret.pivot_table(index = ['index_id','datetime'],columns='fund_id',values='ret')
+        self.fund_ret = self.fund_ret.stack().reset_index(level=[0,1]).rename(columns={0:'ret'})
+        self.fund_ret = self.fund_ret.pivot_table(index='datetime',columns='fund_id',values='ret')        
+        # self.fund_ret['index_id'] = self.fund_ret.fund_id.apply(lambda x: self.fund_to_index_dict[x])
+        # self.fund_ret = self.fund_ret.pivot_table(index = ['index_id','datetime'],columns='fund_id',values='ret')
         self.index_ret = np.log(self.index_price / self.index_price.shift(1))
         self.fund_to_index_dict = {fund_id:index_id for fund_id,index_id in self.fund_to_index_dict.items() if fund_id in self.fund_ret.columns}
-        self.index_list = self.fund_ret.index.levels[0]
+        self.index_list = self.fund_info.index_id.dropna().unique().tolist()
         self.index_fund = { index_id : [fund_idx for fund_idx, index_idx in self.fund_to_index_dict.items() if index_idx == index_id] for index_id in self.index_list}
         self.start_date_dic = self.fund_info[['fund_id','start_date']].set_index('fund_id').to_dict()['start_date']
 
@@ -233,8 +235,10 @@ class FundIndicatorProcessor(object):
         index_list = self.index_list if index_id_list is None else index_id_list
         for index_id in index_list:
             time_range = self.get_time_range(index_id)
-            fund_list = self.index_fund[index_id]
-            fund_ret = self.fund_ret.loc[index_id][fund_list].copy()
+            fund_list_1 = self.index_fund[index_id]
+            fund_list_2 = self._dm.dts.active_fund_info[self._dm.dts.active_fund_info['index_id'] == index_id].fund_id.tolist()
+            fund_list = list(set(fund_list_1).union(set(fund_list_2)))
+            fund_ret = self.fund_ret[fund_list].copy()
             index_ret = self.index_ret[[index_id]]
             with concurrent.futures.ProcessPoolExecutor(max_workers=cpu_num) as executor:
                 future_to_bti = {executor.submit(self._process_fund_indicator_one, fund_id, time_range, fund_ret, index_id, index_ret): fund_id for fund_id in fund_list}
@@ -257,8 +261,10 @@ class FundIndicatorProcessor(object):
         index_list = self.index_list
         for index_id in index_list:
             time_range = self.get_time_range(index_id)
-            fund_list = self.index_fund[index_id]
-            fund_ret = self.fund_ret.loc[index_id][fund_list].copy()
+            fund_list_1 = self.index_fund[index_id]
+            fund_list_2 = self._dm.dts.active_fund_info[self._dm.dts.active_fund_info['index_id'] == index_id].fund_id.tolist()
+            fund_list = list(set(fund_list_1).union(set(fund_list_2)))
+            fund_ret = self.fund_ret[fund_list].copy()
             index_ret = self.index_ret[[index_id]]
             for fund_id in fund_list:
                 result.append(self._process_fund_indicator_update(fund_id, time_range, fund_ret, index_id, index_ret))
