@@ -11,6 +11,7 @@ from ...view.derived_models import IndexValuationLongTerm, IndexReturn, IndexVol
 from ....util.calculator import Calculator as SurfingCalculator
 from ...view.cas.tag_method_index_level import TagMethodIndexLevel
 from ....data.api.derived import DerivedDataApi
+from ....constant import SectorType
 
 class IndexDailyCollectionProcessor(object):
     def get_index_volatility(self):
@@ -121,7 +122,7 @@ class IndexDailyCollectionProcessor(object):
                     IndexComponent.id_cat,
                 )
                 df = pd.read_sql(query.statement, query.session.bind)
-                df['id_cat'] = df['id_cat'].apply(lambda x: x.name)
+                df['id_cat'] = df['id_cat'].transform(lambda x: SectorType(x).name)
                 df = df.set_index('index_id')
                 return df
 
