@@ -11,20 +11,30 @@ class FundDataTables:
     trading_days: pd.DataFrame = None
     index_info: pd.DataFrame = None
     index_price: pd.DataFrame = None
+    _index_pct_df: pd.DataFrame = None
     index_pct: pd.DataFrame = None
     fund_info: pd.DataFrame = None
-    fund_score: pd.DataFrame = None
+    fund_benchmark_info: pd.DataFrame = None
+    active_fund_info: pd.DataFrame = None
     fund_nav: pd.DataFrame = None
-    fund_indicator: pd.DataFrame = None
     fund_unit_nav: pd.DataFrame = None
     fund_size: pd.DataFrame = None
     fund_com_hold: pd.DataFrame = None
+    fund_manager_score: pd.DataFrame = None
+    fund_manager_info: pd.DataFrame = None
+    fund_manager_rank: pd.DataFrame = None
+    # derived
+    fund_indicator: pd.DataFrame = None
+    fund_indicator_annual: pd.DataFrame = None
+    _barra_cne5_factor_return: pd.DataFrame = None
     # fund helps
     fund_list: set = None
+    all_fund_list: set= None
     index_list: set = None
-    fund_index_map: dict = None # fund_id -> index_id
+    fund_index_map: dict = None  # fund_id -> index_id
+    index_date_list: list = None
     # score helps
-    index_fund_indicator_pack: pd.DataFrame = None # pivot_table
+    index_fund_indicator_pack: pd.DataFrame = None  # pivot_table
 
     def __post_init__(self):
         self.fund_list = self.fund_list or set([])
@@ -40,7 +50,7 @@ class FundDataTables:
     def _agg_indicator(self):
         self.fund_indicator = self.fund_indicator.rename(columns={'var':'var_'})
         self.index_fund_indicator_pack = self.fund_indicator.pivot_table(index=['index_id', 'datetime', 'fund_id'])
-        self.index_list = set(self.index_fund_indicator_pack.index.levels[0])
+        self.index_list = set(self.index_fund_indicator_pack.index.levels[0]).union(['active'])
 
     def fix_data(self):
         # 将 fix_data_v1 去掉的原因是目前 basic 改用choice数据源，nav数据没有这个问题了。
