@@ -105,7 +105,8 @@ class FundStatusLatest(Base):
     PURCHSTATUS = Column('purch_status', CHAR(16))  # 申购状态
     REDEMSTATUS = Column('redem_status', CHAR(16))  # 赎回状态
     LPLIMIT = Column('lp_limit', DOUBLE(asdecimal=False))  # 暂停大额申购上限
-    OTCLPLIMIT = Column('otc_lp_limit', DOUBLE(asdecimal=False))  # 场外暂停大额申购上限
+    OTCLPLIMITJG = Column('otc_lp_limit_jg', DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(机构)
+    OTCLPLIMITGR = Column('otc_lp_limit_gr', DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(个人)
     TRADESTATUS = Column('trade_status', CHAR(16))  # 交易状态
 
 
@@ -160,6 +161,9 @@ class FundInfo(Base):
     pre_fund_manager = Column(TEXT)  # 基金经理(历任)
     custodian_bank = Column(CHAR(64))  # 基金托管人
     foreign_custodian = Column(CHAR(64))  # 境外托管人
+    frontend_fee_code = Column(CHAR(12))   # 前端收费代码
+    backend_fee_code = Column(CHAR(12))  # 后端收费代码
+    ar_code_in = Column(CHAR(12))  # 场内申赎代码
 
 
 class FundBenchmark(Base):
@@ -590,3 +594,26 @@ class FundCompCoreMng(Base):
     com_core_mng_resign_rate = 	Column(DOUBLE(asdecimal=False)) #基金公司核心人员离职率(%)
     fund_type = Column(CHAR(25)) # 基金类型
     region = Column(CHAR(5)) # 监管辖区
+
+class FundIPOStats(Base):
+    '''基金打新收益率统计'''
+
+    __tablename__ = 'fund_ipo_stats'
+
+    fund_id = Column(CHAR(10), primary_key=True) # 代码
+    end_date = Column(DATE, primary_key=True) # 结束统计日
+    ipo_allocation_num = Column(Integer) # 打中新股数量
+    ipo_allocation_share_num = Column(DOUBLE(asdecimal=False)) # 累计获配股数(万股)
+    ipo_allocation_amount = Column(DOUBLE(asdecimal=False)) # 累计获配金额(万元)
+    ipo_allocation_ret = Column(DOUBLE(asdecimal=False)) # 打新收益率(%)
+    start_date = Column(DATE)  # 开始统计日期
+
+class FundConvStats(Base):
+    '''基金可转债比例'''
+
+    __tablename__ = 'fund_conv_stats'
+
+    fund_id = Column(CHAR(10), primary_key=True) # 代码
+    datetime = Column(DATE, primary_key=True) # 日期
+    conv_weights = Column(DOUBLE(asdecimal=False)) # 可转债权重
+
