@@ -1,4 +1,4 @@
-from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text
+from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.dialects.mysql import DOUBLE, DATE, DATETIME
 
@@ -279,7 +279,7 @@ class FundScore(Base):
 
 
 class FundScoreExtended(Base):
-    '''基金评分(新)'''
+    '''新基金评分v1'''
 
     __tablename__ = 'fund_score_extended'
 
@@ -322,6 +322,25 @@ class FundScoreExtended(Base):
         Index('idx_fund_score_extended_datetime', 'datetime'),
     )
 
+class FundScoreNew(Base):
+    '''新基金评分v2'''
+
+    __tablename__ = 'fund_score_new'
+
+    fund_id = Column(CHAR(16), primary_key=True)  # 基金代码
+    datetime = Column(DATE, primary_key=True)  # 日期
+    wind_class_1 = Column(CHAR(16))  # Wind基金一级类型
+    return_score = Column(DOUBLE(asdecimal=False))  # 被动指数型、被动指数型债券(均为二级分类)基金为跟踪标的能力，其他为收益能力
+    robust_score = Column(DOUBLE(asdecimal=False))  # 稳定性能力
+    risk_score = Column(DOUBLE(asdecimal=False))  # 抗风险能力
+    timing_score = Column(DOUBLE(asdecimal=False))  # 被动指数型、被动指数型债券(均为二级分类)基金和货基(一二级分类相同)为管理规模能力，其他为择时能力
+    selection_score = Column(DOUBLE(asdecimal=False))  # 被动指数型、被动指数型债券(均为二级分类)基金和货基(一二级分类相同)为机构观点，其他为选证能力
+    team_score = Column(DOUBLE(asdecimal=False))  # 基金公司团队能力
+    total_score = Column(DOUBLE(asdecimal=False), nullable=False)  # 总分
+
+    __table_args__ = (
+        Index('idx_fund_score_new_datetime', 'datetime'),
+    )
 
 class AssetAllocationInfo(Base):
     '''十档大类资产组合'''
@@ -419,11 +438,15 @@ class StyleBox(Base):
     '''基金风格九宫格评分'''
 
     __tablename__ = 'fund_style_box'
+
     fund_id = Column(CHAR(20), primary_key=True)  # 基金ID
-    datetime = Column(CHAR(20), primary_key=True)  # 时间
+    datetime = Column(DATE, primary_key=True)  # 时间
     x = Column(DOUBLE(asdecimal=False))  # 价值-平衡-成长维度
     y = Column(DOUBLE(asdecimal=False))  # 小盘-中盘-大盘维度
 
+    __table_args__ = (
+        Index('idx_fund_style_box_datetime', 'datetime'),
+    )
 
 class StyleReg(Base):
     '''Style 因子收益'''
@@ -457,24 +480,64 @@ class FundManagerScore(Base):
     manager_id = Column(CHAR(16), primary_key=True)  # 基金经理ID
     datetime = Column(DATE, primary_key=True)  # 日期
     fund_type = Column(CHAR(8), primary_key=True)  # 所管理基金类型
-    start_date = Column(DATE)
     trade_year = Column(DOUBLE(asdecimal=False))
-    last_unit_nav = Column(DOUBLE(asdecimal=False))
     annualized_ret = Column(DOUBLE(asdecimal=False))
     annualized_vol = Column(DOUBLE(asdecimal=False))
     sharpe = Column(DOUBLE(asdecimal=False))
-    recent_y5_ret = Column(DOUBLE(asdecimal=False))
     mdd = Column(DOUBLE(asdecimal=False))
-    mdd_date1 = Column(DOUBLE(asdecimal=False))
-    mdd_date2 = Column(DOUBLE(asdecimal=False))
-    ret_over_mdd = Column(DOUBLE(asdecimal=False))
-    last_mv_diff = Column(DOUBLE(asdecimal=False))
-    last_increase_rate = Column(DOUBLE(asdecimal=False))
     alpha = Column(DOUBLE(asdecimal=False))
     beta = Column(DOUBLE(asdecimal=False))
     track_err = Column(DOUBLE(asdecimal=False))
-    ir = Column(DOUBLE(asdecimal=False))
     model_alpha = Column(DOUBLE(asdecimal=False))
     model_beta = Column(DOUBLE(asdecimal=False))
     score = Column(DOUBLE(asdecimal=False))
 
+
+class FundManagerInfo(Base):
+    '''基金经理信息'''
+    __tablename__ = 'manager_info'
+
+    mng_id = Column(CHAR(10), primary_key=True) # 基金经理id
+    start_date = Column(DATE, primary_key=True) # 基金经理任职时间
+    fund_id = Column(CHAR(10), primary_key=True) # 代码
+    mng_name = Column(CHAR(25)) # 基金经理
+    gender = Column(CHAR(2)) # 性别
+    birth_year = Column(CHAR(4)) # 出生年份
+    education = Column(CHAR(4)) # 学历
+    nationality = Column(CHAR(10)) # 国籍
+    resume = Column(TEXT) # 简历
+    end_date = Column(DATE) # 基金经理离职时间
+
+
+class FundManagerFundRank(Base):
+    '''基金经理基金排名'''
+    __tablename__ = 'manager_fund_rank'
+
+    mng_id = Column(CHAR(10), primary_key=True) # 基金经理id
+    datetime = Column(DATE, primary_key=True) # 时间
+    fund_list = Column(TEXT)
+
+
+class NewShareFundRank(Base):
+    """打新基金榜单"""
+    __tablename__ = 'fund_rank_new_share'
+
+    fund_id = Column(CHAR(10), primary_key=True)        # 基金ID
+    final_score = Column(DOUBLE(asdecimal=False))       # 最终分数
+
+
+class AbsReturnFundRank(Base):
+    """绝对收益基金榜单"""
+    __tablename__ = 'fund_rank_abs_return'
+
+    fund_id = Column(CHAR(10), primary_key=True)        # 基金ID
+    final_score = Column(DOUBLE(asdecimal=False))       # 最终分数
+
+
+class ConvertibleBondFundRank(Base):
+    """可转债基金榜单"""
+    __tablename__ = 'fund_rank_convertible_bonds'
+
+    fund_id = Column(CHAR(10), primary_key=True)        # 基金ID
+    final_score = Column(DOUBLE(asdecimal=False))       # 最终分数
+
