@@ -498,7 +498,8 @@ class EmFundScale(Base):
     PURCHSTATUS = Column(CHAR(16))  # 申购状态
     REDEMSTATUS = Column(CHAR(16))  # 赎回状态
     LPLIMIT = Column(DOUBLE(asdecimal=False))  # 暂停大额申购上限
-    OTCLPLIMIT = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限
+    OTCLPLIMITJG = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(机构)
+    OTCLPLIMITGR = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(个人)
     TRADESTATUS = Column(CHAR(16))  # 交易状态
 
 
@@ -824,6 +825,9 @@ class EmFundInfo(Base):
     MGRCOMP = Column('company_id', CHAR(64), nullable=False) # 基金公司名称
     CUSTODIANBANK = Column('custodian_bank', CHAR(64))  # 基金托管人
     FOREIGNCUSTODIAN = Column('foreign_custodian', CHAR(64))  # 境外托管人
+    FRONTENDFEECODE = Column('frontend_fee_code', CHAR(12))   # 前端收费代码
+    BACKENDFEECODE = Column('backend_fee_code', CHAR(12))  # 后端收费代码
+    ARCODEIN = Column('ar_code_in', CHAR(12))  # 场内申赎代码
 
 class EmFundBenchmark(Base):
     '''Choice基金业绩比较基准表'''
@@ -936,8 +940,8 @@ class WindFundManager(Base):
     __tablename__ = 'wind_fund_manager'
 
     F_INFO_FUNDMANAGER_ID = Column(CHAR(10), primary_key=True) # 基金经理ID
-    ANN_DATE = Column(CHAR(8), primary_key=True) # 报告日期
-    F_INFO_WINDCODE = Column(CHAR(20)) # 万德基金ID
+    F_INFO_WINDCODE = Column(CHAR(20),  primary_key=True) # 万德基金ID
+    ANN_DATE = Column(CHAR(8),  primary_key=True) # 报告日期
     F_INFO_FUNDMANAGER = Column(CHAR(10)) # 姓名
     F_INFO_MANAGER_GENDER = Column(CHAR(1)) # 性别
     F_INFO_MANAGER_BIRTHYEAR = Column(CHAR(4)) # 出生年份
@@ -1277,3 +1281,111 @@ class EmBondRating(Base):
     __table_args__ = (
         Index('idx_em_bond_rating_datetime', 'datetime'),
     )
+
+class EmMacroEconomicMonthly(Base):
+    '''Choice宏观经济数据(月度)'''
+
+    __tablename__ = 'em_macro_economic_monthly'
+
+    # CPI: 当月同比
+    # PPI: 全部工业品：当月同比
+    # M1: 同比
+    # M2: 同比
+    # AFtoRE: 社会融资规模存量增速
+    # IVA: 工业增加值：当月同比
+    # PMI:
+    # CX_PMI: 汇丰（财新）PMI
+    # SOC_RG: 社会消费品零售总额：当月同比
+    codes = Column(CHAR(12), primary_key=True)
+    datetime = Column(DATE, primary_key=True) # 日期
+
+    value = Column(DOUBLE(asdecimal=False)) # 数据
+
+
+class EmMacroEconomicDaily(Base):
+    '''Choice宏观经济数据(日度)'''
+
+    __tablename__ = 'em_macro_economic_daily'
+
+    # TB_1Y: 中债国债到期收益率：1年
+    # TB_10Y: 中债国债到期收益率：10年
+    # CB_AAA_1Y: 交易所公司债到期收益率(AAA):1年
+    codes = Column(CHAR(12), primary_key=True)
+    datetime = Column(DATE, primary_key=True) # 日期
+
+    value = Column(DOUBLE(asdecimal=False)) # 数据
+
+class EmFundIPOStats(Base):
+    '''基金打新收益率统计'''
+
+    __tablename__ = 'em_fund_ipo_stats'
+
+    em_id = Column(CHAR(10), primary_key=True) # 代码
+    end_date = Column(DATE, primary_key=True) # 结束统计日
+    ipo_allocation_num = Column(Integer) # 打中新股数量
+    ipo_allocation_share_num = Column(DOUBLE(asdecimal=False)) # 累计获配股数(万股)
+    ipo_allocation_amount = Column(DOUBLE(asdecimal=False)) # 累计获配金额(万元)
+    ipo_allocation_ret = Column(DOUBLE(asdecimal=False)) # 打新收益率(%)
+    start_date = Column(DATE)  # 开始统计日期
+
+class EmFundConvInfo(Base):
+    '''可转债发行'''
+
+    __tablename__ = 'em_fund_conv_info'
+    issue_date = Column(DATE, primary_key=True) # 发行日期
+    conv_bond_id = Column(CHAR(10), primary_key=True) # 转债代码
+    bond_name = Column(CHAR(64), primary_key=True) # 转债名称
+    em_id = Column(CHAR(10)) #代码
+    desc_name = Column(CHAR(64)) # 基金名称名称
+    conv_bond_id = Column(CHAR(10)) # 转债代码
+    ipo_method = Column(TEXT) # 发行方式
+    ipo_size = Column(DOUBLE(asdecimal=False)) # 发行规模(亿元)
+    duration = Column(DOUBLE(asdecimal=False)) # 发行期限(年)
+    rating = Column(CHAR(10)) # 信用评级
+    coupon_rate = Column(DOUBLE(asdecimal=False)) # 票面利率(%)
+    compensation_rate = Column(DOUBLE(asdecimal=False)) # 补偿利率(%)
+    rate_type = Column(CHAR(15)) # 利率类型
+    latest_balance = Column(DOUBLE(asdecimal=False)) # 最新余额(万元)
+    payment_frequency = Column(CHAR(15)) # 付息频率
+    payment_doc = Column(CHAR(15)) # 付息说明
+    listing_date = Column(DATE) # 上市日期
+    value_date = Column(DATE) # 起息日期
+    date_of_expiry = Column(DATE) # 到期日期
+    conv_start_date = Column(DATE) # 转股起始日
+    init_conv_price = Column(DOUBLE(asdecimal=False)) # 初始转股价
+    latest_conv_price = Column(DOUBLE(asdecimal=False)) # 最新转股价
+    rate_doc = Column(TEXT) # 利率说明
+    redemption_clause = Column(TEXT) # 赎回条款
+    resale_clause = Column(TEXT) # 回售条款
+    downward_amendment = Column(TEXT) # 特别向下修正条款
+    conv_clause = Column(TEXT) # 转股条款
+    warrent = Column(CHAR(100)) # 担保人
+    warrent_method = Column(CHAR(30)) # 担保方式
+    warrent_scope = Column(TEXT) # 担保范围
+    credit_rating = Column(CHAR(10)) # 信用等级
+    evaluation_agency = Column(CHAR(50)) # 评估机构
+    lead_underwriter = Column(TEXT) # 主承销商
+    industry = Column(CHAR(40)) # 证监会行业(2012)
+    em_industry = Column(CHAR(20)) # 东财行业
+
+class EmFundIPODetail(Base):
+    '''打新明细''' 
+    #TODO 东财这部分下数据接口在11月上限，当前没有直接使用，通过客户端接口下载csv数据倒入数据库，只有一个基金明细
+
+    __tablename__ = 'em_fund_ipo_detail'
+    stock_id = Column(CHAR(10), primary_key=True) # 代码
+    em_id = Column(CHAR(10), primary_key=True) # 基金代码
+    desc_name = Column(CHAR(20)) # 名称
+    placedate = Column(DATE) # 配售日期
+    effective_volume = Column(DOUBLE(asdecimal=False)) # 有效申购数量(万股)
+    actual_volume = Column(DOUBLE(asdecimal=False)) # 实际配售数量(万股)
+    place_rate = Column(DOUBLE(asdecimal=False)) # 获配比例(%)
+    place_amt = Column(DOUBLE(asdecimal=False)) # 获配金额(万元)
+    lock_up_period = Column(TEXT) # 锁定期限
+    issue_price = Column(DOUBLE(asdecimal=False)) # 发行价格(元)
+    first_open_d_ret = Column(DOUBLE(asdecimal=False)) # 首个开板日涨跌幅(%)
+    historcal_ret = Column(DOUBLE(asdecimal=False)) # 上市以来最高涨幅(%)
+    ipo_allocation_ret = Column(DOUBLE(asdecimal=False)) # 打新收益率(%)
+    annual_allocation_ret = Column(DOUBLE(asdecimal=False)) # 年化打新收益率(%)
+    industry = Column(CHAR(40)) # 证监会行业(2012)
+    em_industry = Column(CHAR(20)) # 东财行业
