@@ -33,6 +33,8 @@ class FundDailyCollection(Base):
     redem_status = Column(CHAR(16))  # 赎回状态
     lp_limit = Column(DOUBLE(asdecimal=False))  # 暂停大额申购上限
     otc_lp_limit = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限
+    otc_lp_limit_jg = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(机构)
+    otc_lp_limit_gr = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(个人)
 
     unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))  # 累计单位净值
@@ -115,6 +117,14 @@ class FundDailyCollection(Base):
     tag_name = Column(CHAR(64)) # 基金类别
     score = Column(DOUBLE(asdecimal=False)) # 评分
 
+    return_score = Column(DOUBLE(asdecimal=False))  # 被动指数型、被动指数型债券(均为二级分类)基金为跟踪标的能力，其他为收益能力
+    robust_score = Column(DOUBLE(asdecimal=False))  # 稳定性能力
+    risk_score = Column(DOUBLE(asdecimal=False))  # 抗风险能力
+    timing_score = Column(DOUBLE(asdecimal=False))  # 被动指数型、被动指数型债券(均为二级分类)基金和货基(一二级分类相同)为管理规模能力，其他为择时能力
+    selection_score = Column(DOUBLE(asdecimal=False))  # 被动指数型、被动指数型债券(均为二级分类)基金和货基(一二级分类相同)为机构观点，其他为选证能力
+    team_score = Column(DOUBLE(asdecimal=False))  # 基金公司团队能力
+    total_score = Column(DOUBLE(asdecimal=False), nullable=False)  # 总分
+
     @staticmethod
     def trans_columns():
         return {
@@ -133,6 +143,8 @@ class FundDailyCollection(Base):
             'redem_status': '赎回状态',
             'lp_limit': '暂停大额申购上限',
             'otc_lp_limit': '场外暂停大额申购上限',
+            'otc_lp_limit_jg': '场外暂停大额申购上限(机构)',
+            'otc_lp_limit_gr': '场外暂停大额申购上限(个人)',
 
             'theme': '基金主题',
             'adjusted_net_value': '复权净值',
@@ -212,6 +224,14 @@ class FundDailyCollection(Base):
 
             'tag_name': '基金类别',
             'score': '基金评分',
+
+            'return_score': '收益能力',
+            'robust_score': '稳定性能力',
+            'risk_score': '抗风险能力',
+            'timing_score': '择时能力',
+            'selection_score': '选证能力',
+            'team_score': '团队能力',
+            'total_score': '总分',
         }
 
 
