@@ -15,15 +15,15 @@ from ...data.constant import _DEFAULT_CASH_VALUE
 from ...data.struct import FundTrade, FundWeight, FundWeightItem
 from ...data.manager.manager_fund import FundDataManager
 from ...data.manager.score import ScoreFunc, FundScoreManager
-from ...data.struct import AssetWeight, AssetPrice, AssetPosition, AssetValue
-from ...data.struct import FundPosition, TAAParam, AssetTradeParam, FundTradeParam, FAParam
+from ...data.struct import AssetWeight, AssetPrice, AssetPosition, AssetValue, ScoreSelect
+from ...data.struct import FundPosition, TAAParam, AssetTradeParam, FundTradeParam, FAParam, ScoreType
 from ...util.calculator import Calculator
 
 class FundEngine:
 
     DEFAULT_CASH_VALUE = _DEFAULT_CASH_VALUE
 
-    def __init__(self, data_manager: FundDataManager, trader, taa_params:TAAParam=None, fa_params:FAParam=None, taa_param_details:dict=None, is_old_version=False, white_list:set=None, black_list:set=None, fund_score_funcs: Optional[Dict[str, Union[ScoreFunc, str]]] = None):
+    def __init__(self, data_manager: FundDataManager, trader, taa_params:TAAParam=None, fa_params:FAParam=None, taa_param_details:dict=None, is_old_version=False, white_list:set=None, black_list:set=None, fund_score_funcs: Optional[Dict[str, Union[ScoreFunc, str]]] = None, score_select:ScoreSelect=None):
         self._dm = data_manager
         self._saa_helper = SAAHelper()
         self._taa_helper = TAAHelper(taa_params=taa_params, taa_param_details=taa_param_details) if taa_params or taa_param_details else None 
@@ -41,13 +41,17 @@ class FundEngine:
         # 黑白名单和全部基金列表处理 得到不允许交易基金列表， 对其中基金评分惩罚
         self.white_list = white_list
         self.black_list = black_list
-        self.whole_list = set(self._dm.dts.fund_list)
+        self.whole_list = set(self._dm.dts.all_fund_list)
         disproved_set_1 = self.whole_list - self.white_list if self.white_list else set([]) 
         disproved_set_2 = self.black_list if self.black_list else set([])
         self.disproved_set = disproved_set_1.union(disproved_set_2)
         assert not self.is_fund_backtest or self._fa_helper, 'if this is a fund backtest, fa_helper is necessary'
         if self.is_fund_backtest:
             self._trader.set_helper(self._fa_helper)
+        self.score_select = ScoreSelect.__dict__ if score_select is None else score_select.__dict__
+        if fund_score_funcs is not None:
+            for index_id in fund_score_funcs:
+                self.score_select[index_id] = ScoreType.Temp
 
     def init(self):
         if not self._dm.inited:
@@ -67,6 +71,9 @@ class FundEngine:
         self._prep_fund_score_raw = None
         self._prep_target_asset_allocation = None
         self._prep_target_fund_allocation = None
+        self._prep_manager_score = None
+        self._prep_manager_funds = None
+        self._prep_manager_score_cleaned = None
 
     def setup(self, saa: AssetWeight):
         # setup helpers
@@ -93,12 +100,16 @@ class FundEngine:
         self._prep_fund_nav = self._dm.get_fund_nav(dt) if self.is_fund_backtest else {}
         self._prep_fund_unit_nav = self._dm.get_fund_unit_nav(dt) if self.is_fund_backtest else {}
         self._prep_fund_score, self._prep_fund_score_raw = self._dm.get_fund_scores(dt=dt, fund_score_funcs=self._fund_score_funcs) if self.is_fund_backtest else ({}, {})
-        self._prep_fund_score, self._prep_fund_score_raw = self._dm.white_and_black_list_filter(self._prep_fund_score, self._prep_fund_score_raw, self.disproved_set)
-
+        self._prep_manager_score, self._prep_manager_funds, self._prep_manager_score_cleaned = self._dm.get_manager_scores(dt, self.score_select)
+        self._prep_fund_score['active'] = self._prep_manager_score
+        self._prep_fund_score_raw['active'] = self._prep_manager_score
+            
+        if self.disproved_set:
+            self._prep_fund_score, self._prep_fund_score_raw = self._dm.white_and_black_list_filter(self._prep_fund_score, self._prep_fund_score_raw, self.disproved_set)
         # ALLOCATION
         self._prep_target_asset_allocation = self.calc_asset_allocation(dt)
         self._prep_target_fund_allocation = self.calc_fund_allocation(dt) if self.is_fund_backtest else None
-
+       
     def calc_trade(self, dt, cur_asset_position: AssetPosition, cur_fund_position: FundPosition=None, is_real_trade=False):
         if not self.is_fund_backtest:
             v_asset_position, asset_trade_list = self._trader.calc_asset_trade(dt, cur_asset_position, self._prep_asset_price, self._prep_target_asset_allocation)
@@ -121,7 +132,8 @@ class FundEngine:
             v_fund_position, fund_trade_list, trigger_reason = self._trader.calc_trade(
                 dt, self._prep_target_fund_allocation, self._prep_target_asset_allocation,
                 cur_fund_position, cur_asset_position, 
-                self._prep_fund_nav, self._prep_fund_score, self._prep_asset_price,self._prep_fund_unit_nav, is_real_trade
+                self._prep_fund_nav, self._prep_fund_score, self._prep_asset_price,self._prep_fund_unit_nav, 
+                is_real_trade, self._prep_manager_funds, self.score_select
             )
             self._report_helper.update_rebalance_detail(dt, trigger_reason)
             return fund_trade_list
@@ -130,7 +142,7 @@ class FundEngine:
         if self.is_fund_backtest:
             assert cur_fund_position, 'cur_fund_position should not be None in fund backtest run'
             self._pending_trades, traded_list = self._trader.finalize_trade(dt, trades, self._prep_asset_price, cur_asset_position, cur_fund_position, self._prep_fund_nav, self._prep_fund_unit_nav,
-                self._prep_fund_purchase_fees, self._prep_fund_redeem_fees, disproved_set)
+                self._prep_fund_purchase_fees, self._prep_fund_redeem_fees, disproved_set, self._prep_target_fund_allocation)
         else:
             self._pending_trades, traded_list = self._trader.finalize_trade(dt, trades, self._prep_asset_price, cur_asset_position)
         return traded_list 
@@ -146,7 +158,7 @@ class FundEngine:
         return cur_taa
 
     def calc_fund_allocation(self, dt):
-        return self._fa_helper.on_price(dt, self._prep_target_asset_allocation, self._prep_fund_score)
+        return self._fa_helper.on_price(dt, self._prep_target_asset_allocation, self._prep_fund_score, self._prep_manager_score_cleaned, self.score_select)
 
     def update_reporter(self, dt, trade_list, cur_asset_position: AssetPosition, cur_fund_position: FundPosition=None):
         self._report_helper.update(dt, cur_asset_position, self._prep_asset_price, self._pending_trades, cur_fund_position if self.is_fund_backtest else None, self._prep_fund_nav, trade_list, self._prep_fund_score, self._prep_fund_score_raw, self._prep_target_asset_allocation)
@@ -176,7 +188,7 @@ class FundBacktestEngine(FundEngine):
         for t in dts:
             self._run_on(t, print_time=print_time)
         # init report data
-        self._report_helper.plot_init(self._dm, self._taa_helper)
+        self._report_helper.plot_init(self._dm, self._taa_helper, self.score_select)
         #print(self._report_helper.get_fund_stat())
 
     def _run_on(self, dt, print_time=False):
@@ -195,9 +207,8 @@ class FundBacktestEngine(FundEngine):
         # update
         self.update_reporter(dt, traded_list, self.cur_asset_position, self.cur_fund_position)        
         _tm_finish = time.time()
-
         if print_time:
-            print(f'{dt} (tot){_tm_finish - _tm_start} (finalize){_tm_finalize_trade - _tm_start} (calc){_tm_calc_trade - _tm_finalize_trade} (misc){_tm_finish - _tm_calc_trade}')
+            print(f'{dt} (tot){_tm_finish - _tm_start} (prep_data) {_tm_prep_data - _tm_start}  (finalize){_tm_finalize_trade - _tm_prep_data} (calc){_tm_calc_trade - _tm_finalize_trade} (misc){_tm_finish - _tm_calc_trade}')
 
     def book_trades(self, trade_list: list):
         if trade_list and len(trade_list) > 0:
@@ -478,7 +489,7 @@ def taa_result(m: FundDataManager):
                         LowPlus = 0.06) 
     return ReportHelper.get_taa_result(index_id=index_id, start_date=start_date, end_date=end_date, taaParam=taaParam, dm=m)
 
-def four_dimensions_backtest(m,begin_date, end_date, saa, fund_param, taa_detail):
+def four_dimensions_backtest(m,begin_date, end_date, saa, fund_param, taa_detail, score_select=None):
     asset_param = AssetTradeParam() 
     t = AssetTrader(asset_param)
     saa_bk = FundBacktestEngine(data_manager=m, trader=t, taa_params=None)
@@ -495,7 +506,7 @@ def four_dimensions_backtest(m,begin_date, end_date, saa, fund_param, taa_detail
     
     t = FundTrader(asset_param, fund_param)
     fa_param = FAParam() 
-    fund_taa = FundBacktestEngine(data_manager=m, trader=t, taa_params=None, fa_params=fa_param, taa_param_details=taa_detail)
+    fund_taa = FundBacktestEngine(data_manager=m, trader=t, taa_params=None, fa_params=fa_param, taa_param_details=taa_detail, score_select=score_select)
     fund_taa.init()
     fund_taa.run(saa=saa,start_date=begin_date,end_date=end_date)
     fund_result = fund_taa.get_fund_result()
