@@ -201,6 +201,8 @@ class HybridPainter(object):
                         backtest_result:dict,
                         dts:pd.Series,
                         saa:dict,
+                        fund_trade: pd.DataFrame,
+                        score_select: dict,
                         ):
         
         proper_number_dict = {'mmf':1} 
@@ -222,8 +224,9 @@ class HybridPainter(object):
             end_date = rebalance_date[idx + 1]
             for asset, num in proper_number_dict.items():
                 #print(asset, num)
-                _score_dict = score_dict[begin_date][asset]
+                _score_dict = score_dict[begin_date][asset][score_select[asset]]
                 _score_list = sorted(_score_dict.items(), key=lambda x:x[1], reverse=True)
+                #_fund_list = fund_trade[(fund_trade['trade_date'] == begin_date) & (fund_trade['is_buy']) & (fund_trade['index_id'] == asset)].fund_id.tolist()
                 _fund_list = [i[0] for i in _score_list]
                 dic = {
                     'index_id':asset,
@@ -351,7 +354,7 @@ class HybridPainter(object):
         return result_df, pos_df
 
     @staticmethod
-    def fund_rank_recent_analysis(fund_id,index_id,score_dict,fund_info,fund_indicator,fund_nav,index_price,score_func):
+    def fund_rank_recent_analysis(fund_id,index_id,score_dict,fund_info,fund_indicator,fund_nav,index_price,score_func,score_select):
 
         _res = []
         indicators = []
@@ -366,7 +369,7 @@ class HybridPainter(object):
         for dt in dts_list:
             _score_dict = score_dict[dt]
             if index_id in _score_dict:
-                _score_dict = _score_dict[index_id]
+                _score_dict = _score_dict[index_id][score_select[index_id]]
             else:
                 continue
             _score_list = sorted(_score_dict.items(), key=lambda x:x[1], reverse=True)
