@@ -42,7 +42,7 @@ class ReportHelper:
     def init(self): 
         pass
 
-    def plot_init(self, dm, taa_helper=None):
+    def plot_init(self, dm, taa_helper=None, score_select=None):
         self.index_price = dm.get_index_price()
         self.fund_info = dm.get_fund_info()
         self.fund_nav = dm.dts.fund_nav
@@ -58,7 +58,13 @@ class ReportHelper:
         self.trade_df = pd.DataFrame(trade_list)
         if not self.trade_df.empty:
             self.trade_df['year'] = [_.year for _ in self.trade_df.trade_date]
-        self.pct_df = dm._index_pct_df
+        self.pct_df = dm.dts._index_pct_df
+        self.score_select = score_select
+        self.active_fund_info = dm.dts.active_fund_info
+        self.fund_info = self.fund_info.set_index('fund_id')
+        for r in self.active_fund_info.itertuples():
+            self.fund_info.loc[r.fund_id,'index_id'] = r.index_id
+        self.fund_info = self.fund_info.reset_index()
 
     def setup(self, saa:AssetWeight=None):
         self.saa_weight = saa.__dict__ if saa else None
@@ -208,7 +214,7 @@ class ReportHelper:
         dt = sorted(list(self.fund_score_dm.keys()))[-1]
         fund_rank = []
         for i in pos_df.itertuples():
-            _score_dict = self.fund_score_dm[dt][i.index_id]
+            _score_dict = self.fund_score_dm[dt][i.index_id][self.score_select[i.index_id]]
             _score_list = sorted(_score_dict.items(), key=lambda x:x[1], reverse=True)
             _fund_list = [i[0] for i in _score_list]
             rank_i = _fund_list.index(i.Index) + 1 if i.Index in _fund_list else 10000
@@ -265,15 +271,15 @@ class ReportHelper:
         return df
 
     @staticmethod
-    def fund_rank_recent_analysis(dm, fund_id):
+    def fund_rank_recent_analysis(dm, fund_id, score_select):
         score_dict = dm._score_manager.score_cache
         fund_info = dm.dts.fund_info
         fund_indicator = dm.dts.fund_indicator
         fund_nav = dm.dts.fund_nav
         index_price = dm.dts.index_price
         index_id = fund_info[fund_info['fund_id'] == fund_id].index_id.values[0]
-        score_func = dm._score_manager.funcs[index_id]
-        return HybridPainter.fund_rank_recent_analysis(fund_id,index_id,score_dict,fund_info,fund_indicator,fund_nav,index_price,score_func)
+        score_func = dm._score_manager.funcs[index_id][score_select[index_id]]
+        return HybridPainter.fund_rank_recent_analysis(fund_id,index_id,score_dict,fund_info,fund_indicator,fund_nav,index_price,score_func,score_select)
 
     def get_asset_trade(self):
         asset_trade = []
@@ -376,7 +382,7 @@ class ReportHelper:
         FundPainter.plot_fund_mdd_periods(self.fund_mv, self.fund_weights_history, self.fund_nav, self.fund_info)
         FundPainter.plot_fund_mdd_amounts(self.fund_mv, self.fund_nav, self.fund_info, self.fund_position_history.copy())
         FundPainter.plot_fund_alpha(self.fund_nav, self.fund_info, self.index_price, self.fund_position_history.copy(), w)
-        FundPainter.plot_mv_on_each_asset(self.fund_nav, self.fund_info, self.index_price, self.fund_position_history.copy(), w)
+        #FundPainter.plot_mv_on_each_asset(self.fund_nav, self.fund_info, self.index_price, self.fund_position_history.copy(), w)
         #HybridPainter.plot_asset_fund_mv_diff(self.asset_mv, self.fund_mv)
         # if not self.index_fee.empty:
         #     FundPainter.plot_index_fund_fee(self.index_fee)
@@ -391,7 +397,8 @@ class ReportHelper:
         FundPainter.plot_fund_alpha(self.fund_nav, self.fund_info, self.index_price, self.fund_position_history.copy(), w)
 
     def asset_price_ratio(self):    
-        return HybridPainter.plot_asset_price_ratio(self.fund_nav, self.fund_info, self.index_price, self.fund_score_dm, self.get_fund_stat(), self.dts, self.saa_weight)
+        fund_trade = self.get_fund_trade()
+        return HybridPainter.plot_asset_price_ratio(self.fund_nav, self.fund_info, self.index_price, self.fund_score_dm, self.get_fund_stat(), self.dts, self.saa_weight, fund_trade, self.score_select)
         
     def plot_whole(self):
         self.backtest_fund_plot()
@@ -410,6 +417,7 @@ class ReportHelper:
                                     self.fund_indicator,
                                     asset,
                                     is_tuning,
+                                    self.score_select,
                                     )
    
     def _index_pct_plot(self, index_id:str, saa_mv:pd.DataFrame, taa_mv:pd.DataFrame):
@@ -568,7 +576,7 @@ class ReportHelper:
         return pd.concat(df_list)
 
     @staticmethod
-    def recent_week_return(pos_df,fund_result,weight_df,saa,mv_df,m,benchmark,end_date=None,begin_date=None,port_id=''):
+    def recent_week_return(pos_df,fund_result,weight_df,saa,mv_df,m,benchmark,end_date=None,begin_date=None,port_id='',fund_info=None):
         # 把买卖交易费平滑打入净值中
         def _index_price_ratio_item(index_ratio_res, d1, d2, is_buy_fee, is_sell_fee):
             _index_ratio_res = []
@@ -607,7 +615,6 @@ class ReportHelper:
             res_df.loc[:,'end_date'] = today
             return res_df
 
-        fund_info = m.dts.fund_info
         buy_dic = (fund_info[['fund_id','purchase_fee']].set_index('fund_id') * 0.15).to_dict()['purchase_fee']
         sell_dic = fund_info[['fund_id','redeem_fee']].set_index('fund_id').to_dict()['redeem_fee']
         index_price = m.dts.index_price
@@ -648,8 +655,8 @@ class ReportHelper:
         #res_df.loc[:,'rets'] = res_df['ret'] * res_df['weight']
         res_df = res_df.sort_values('rets',ascending=False)
         res_df.loc[:,'rets'] = [str(int(i*10000))+'BP' for i in res_df.loc[:,'rets']]
-        desc_dic = m.dts.fund_info[['fund_id','desc_name']].set_index('fund_id').to_dict()['desc_name']
-        index_dic = m.dts.fund_info[['fund_id','index_id']].set_index('fund_id').to_dict()['index_id']
+        desc_dic = fund_info[['fund_id','desc_name']].set_index('fund_id').to_dict()['desc_name']
+        index_dic = fund_info[['fund_id','index_id']].set_index('fund_id').to_dict()['index_id']
         res_df['desc_name'] = res_df.index.map(lambda x : desc_dic[x])
         res_df['index_id'] = res_df.index.map(lambda x : index_dic[x])        
         if begin_date > fund_result['rebalance_date'][-1]:
