@@ -49,9 +49,24 @@ class Calculator:
     def get_risk_free_rate():
         return 0.025
 
+    @staticmethod
+    def get_yearly_multiplier(frequency:str='daily'):
+        # daily weekly 2-weekly monthly yearly
+        if frequency == 'daily':
+            return 1
+        if frequency == 'weekly':
+            return 5
+        if frequency == '2-weekly':
+            return 10
+        if frequency == 'monthly':
+            return 20
+        if frequency == 'yearly':
+            return 242
+
     @staticmethod
     def get_stat_result(dates: pandas.core.series.Series,
-                        values: pandas.core.series.Series):
+                        values: pandas.core.series.Series,
+                        frequency:str='daily'):
         assert len(dates) == len(values), 'date and value has different numbers'
         
         if len(dates) > 1:
@@ -59,13 +74,14 @@ class Calculator:
             risk_fee_rate = Calculator.get_risk_free_rate()
             start_date = sr.index[0] 
             end_date = sr.index[-1]
-            trade_year = sr.shape[0] / Calculator.TRADING_DAYS_PER_YEAR
+            yearly_multiplier = Calculator.get_yearly_multiplier(frequency)
+            trade_year = sr.shape[0] * yearly_multiplier / Calculator.TRADING_DAYS_PER_YEAR
             last_unit_nav = sr[-1] / sr[0]
             annualized_ret = np.exp(np.log(last_unit_nav) / trade_year) - 1
-            annualized_vol = (sr / sr.shift(1)).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR)
+            annualized_vol = (sr / sr.shift(1)).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier)
             sharpe = (annualized_ret - risk_fee_rate) / annualized_vol
-            if sr.shape[0] > Calculator.TRADING_DAYS_PER_YEAR * 5:
-                recent_y5_ret  = sr[-1] / sr[- Calculator.TRADING_DAYS_PER_YEAR * 5] - 1
+            if sr.shape[0] * yearly_multiplier > Calculator.TRADING_DAYS_PER_YEAR * 5:
+                recent_y5_ret  = sr[-1] / sr[- int(Calculator.TRADING_DAYS_PER_YEAR * 5 / yearly_multiplier)] - 1
             else:
                 recent_y5_ret = sr[-1] / sr[0] - 1
             mdd_part =  sr[:] / sr[:].rolling(window=sr.shape[0], min_periods=1).max()
@@ -115,7 +131,8 @@ class Calculator:
 
     @staticmethod
     def get_manager_result(dates: pandas.core.series.Series,
-                          values: pandas.core.series.Series):
+                          values: pandas.core.series.Series,
+                          frequency:str='daily'):
         assert len(dates) == len(values), 'date and value has different numbers'
         
         if len(dates) > 1:
@@ -123,10 +140,11 @@ class Calculator:
             risk_fee_rate = Calculator.get_risk_free_rate()
             start_date = sr.index[0] 
             end_date = sr.index[-1]
-            trade_year = sr.shape[0] / Calculator.TRADING_DAYS_PER_YEAR
+            yearly_multiplier = Calculator.get_yearly_multiplier(frequency)
+            trade_year = sr.shape[0] * yearly_multiplier / Calculator.TRADING_DAYS_PER_YEAR
             last_unit_nav = sr[-1] / sr[0]
             annualized_ret = np.exp(np.log(last_unit_nav) / trade_year) - 1
-            annualized_vol = (sr / sr.shift(1)).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR)
+            annualized_vol = (sr / sr.shift(1)).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier)
             sharpe = (annualized_ret - risk_fee_rate) / annualized_vol
             mdd_part =  sr[:] / sr[:].rolling(window=sr.shape[0], min_periods=1).max()
             mdd = 1 - mdd_part.min()
@@ -154,25 +172,27 @@ class Calculator:
     @staticmethod
     def get_manager_stat_result(dates: pandas.core.series.Series,
                                   values: pandas.core.series.Series,
-                                  benchmark_values: pandas.core.series.Series):
+                                  benchmark_values: pandas.core.series.Series,
+                                  frequency:str='daily'):
         
         assert len(dates) == len(values), 'date and port_values has different numbers'
         assert len(dates) == len(benchmark_values), 'date and bench_values has different numbers'
         res = Calculator.get_manager_result(dates, values)
         sr_values  = pandas.Series(values, index=dates).sort_index()  
         sr_values = sr_values / sr_values[0]
+        yearly_multiplier = Calculator.get_yearly_multiplier(frequency)
         sr_benchmark_values = pandas.Series(benchmark_values, index=dates).sort_index()  
         sr_benchmark_values = sr_benchmark_values / sr_benchmark_values[0]
-        sr_values_ret = sr_values / sr_values.shift(1)
-        sr_benchmark_ret = sr_benchmark_values / sr_benchmark_values.shift(1)
+        sr_values_ret = sr_values.pct_change(1)
+        sr_benchmark_ret = sr_benchmark_values.pct_change(1)
         x = sr_benchmark_ret.dropna().values
         y = sr_values_ret.dropna().values
         x = sm.add_constant(x)
         model = regression.linear_model.OLS(y,x).fit()
         x = x[:,1]
-        alpha = model.params[0]
+        alpha = model.params[0] * Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier
         beta = model.params[1]
-        track_err = (sr_values_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR)
+        track_err = (sr_values_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier)
         
         return {
                 'start_date': res['start_date'],
@@ -191,25 +211,27 @@ class Calculator:
     @staticmethod
     def get_benchmark_stat_result(dates: pandas.core.series.Series,
                                   values: pandas.core.series.Series,
-                                  benchmark_values: pandas.core.series.Series):
+                                  benchmark_values: pandas.core.series.Series,
+                                  frequency:str='daily'):
         
         assert len(dates) == len(values), 'date and port_values has different numbers'
         assert len(dates) == len(benchmark_values), 'date and bench_values has different numbers'
-        res = Calculator.get_stat_result(dates, values)
+        res = Calculator.get_stat_result(dates, values,frequency)
         sr_values  = pandas.Series(values, index=dates).sort_index()  
         sr_values = sr_values / sr_values[0]
         sr_benchmark_values = pandas.Series(benchmark_values, index=dates).sort_index()  
         sr_benchmark_values = sr_benchmark_values / sr_benchmark_values[0]
-        sr_values_ret = sr_values / sr_values.shift(1)
-        sr_benchmark_ret = sr_benchmark_values / sr_benchmark_values.shift(1)
+        yearly_multiplier = Calculator.get_yearly_multiplier(frequency)
+        sr_values_ret = sr_values.pct_change(1)
+        sr_benchmark_ret = sr_benchmark_values.pct_change(1)
         x = sr_benchmark_ret.dropna().values
         y = sr_values_ret.dropna().values
         x = sm.add_constant(x)
         model = regression.linear_model.OLS(y,x).fit()
         x = x[:,1]
-        alpha = model.params[0]
+        alpha = model.params[0] * Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier
         beta = model.params[1]
-        track_err = (sr_values_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR)
+        track_err = (sr_values_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier)
         ir = alpha / track_err
         
         return BenchmarkSeiesStatUnit(
@@ -264,20 +286,23 @@ class Calculator:
     @staticmethod
     def get_stat_result_from_df(df: pandas.DataFrame,
                                 date_column: str,
-                                value_column: str):
+                                value_column: str,
+                                frequency: str = 'daily'):
         dates = df[date_column].values
         values = df[value_column].values
-        return Calculator.get_stat_result(dates, values)
+        return Calculator.get_stat_result(dates, values, frequency)
 
     @staticmethod
     def get_benchmark_stat_result_from_df(df: pandas.DataFrame,
                                           date_column: str,
                                           port_value_column: str,
-                                          bench_value_column: str):
+                                          bench_value_column: str,
+                                          frequency: str = 'daily'
+                                          ):
         dates = df[date_column].values
         port_values = df[port_value_column].values
         bench_values = df[bench_value_column].values
-        return Calculator.get_benchmark_stat_result(dates, port_values, bench_values)
+        return Calculator.get_benchmark_stat_result(dates, port_values, bench_values, frequency)
 
     @staticmethod
     def get_benchmark_result(index_list:list,
